diff --git a/doc/config.html b/doc/config.html
index 974e2430..dba057a5 100755
--- a/doc/config.html
+++ b/doc/config.html
@@ -112,7 +112,7 @@ specified by the Subdir option.
The language setting determines the language of the elogd output. Not
affected by this setting are the configuration file options and the commands specified with the
-optional Menu commands and Find menu commands, which
+optional Menu commands and List menu commands, which
have to be specified in English and are translated automatically by elogd. The attribute names
are unaffected by the language setting and have to be translated manually.
@@ -570,7 +570,7 @@ the current logbook are shown as a possible destination. With the configurations
it is possible to specify a list of destination logbooks, separated by commata. This can
make sense if only certain logbooks make sense as destinations.
-
Find Menu commands = <list>
+List Menu commands = <list>
Guest menu commands option with the following
-Guest Find Menu commands option to restrict the access to the
+Guest List Menu commands option to restrict the access to the
find result page as well.
-
Guest Find Menu commands = <list>
+Guest List Menu commands = <list>
Same as Guest Menu commands but for the find result page.
@@ -633,9 +633,9 @@ if someone is logged in (using the option "Password file"). The
-listtext, if one
wants to display the entry body text for guests.Find Menu text = <file>
+List Menu text = <file>
-The same for the find result page. One example would be following text to
+The same for the list page. One example would be following text to
switch between the different display modi:
diff --git a/src/elogd.c b/src/elogd.c
index bc5302cc..de387124 100755
--- a/src/elogd.c
+++ b/src/elogd.c
@@ -6,6 +6,9 @@
Contents: Web server program for Electronic Logbook ELOG
$Log$
+ Revision 1.684 2005/06/17 20:45:40 ritt
+ Changed 'find menu' to 'list menu'
+
Revision 1.683 2005/06/17 20:31:41 ritt
Fixed bug with user activation and global password files
@@ -15582,11 +15585,17 @@ BOOL is_command_allowed(LOGBOOK * lbs, char *command)
}
}
/* check find menu commands */
str[0] = 0;
- if (!getcfg(lbs->name, "Guest Find Menu commands", str, sizeof(str))
+ if (!getcfg(lbs->name, "Guest List Menu commands", str, sizeof(str))
|| *getparam("unm") != 0)
- getcfg(lbs->name, "Find Menu commands", str, sizeof(str));
+ getcfg(lbs->name, "list menu commands", str, sizeof(str));
+
+ if (!str[0]) {
+ if (!getcfg(lbs->name, "Guest Find Menu commands", str, sizeof(str))
+ || *getparam("unm") != 0)
+ getcfg(lbs->name, "Find Menu commands", str, sizeof(str));
+ }
if (str[0])
strlcat(menu_str, str, sizeof(menu_str));
@@ -17162,6 +17171,12 @@ void show_elog_list(LOGBOOK * lbs, INT past_n, INT last_n, INT page_n, char *inf
|| *getparam("unm") != 0)
getcfg(lbs->name, "Find menu commands", menu_str, sizeof(menu_str));
+ if (!menu_str[0]) {
+ if (!getcfg(lbs->name, "Guest list menu commands", menu_str, sizeof(menu_str))
+ || *getparam("unm") != 0)
+ getcfg(lbs->name, "list menu commands", menu_str, sizeof(menu_str));
+ }
+
/* default menu commands */
if (menu_str[0] == 0) {
strcpy(menu_str, "New, Find, Select, CSV Import, ");
@@ -17224,9 +17239,11 @@ void show_elog_list(LOGBOOK * lbs, INT past_n, INT last_n, INT page_n, char *inf
rsprintf("\n\n");
}
- /*---- find menu text ----*/
+ /*---- list menu text ----*/
- if (getcfg(lbs->name, "find menu text", str, sizeof(str)) && !printable) {
+ if ((getcfg(lbs->name, "find menu text", str, sizeof(str)) ||
+ getcfg(lbs->name, "list menu text", str, sizeof(str)))
+ && !printable) {
FILE *f;
char file_name[256], *buf;
@@ -15582,11 +15585,17 @@ BOOL is_command_allowed(LOGBOOK * lbs, char *command)
}
}
- /* check find menu commands */
+ /* check list menu commands */
str[0] = 0;